@@ -33,6 +33,6 @@ gboolean key_press_cb(GtkWidget* widget, GdkEventKey* event, HildonWindow* windo
 gboolean long_tap(GtkWidget* widget, gpointer data);
 
 // middle event box
-gboolean middle_event_box_button_press(GtkWidget* widget, GdkEventButton* event, gpointer data);
+gboolean short_tap(GtkWidget* widget, GdkEventButton* event, gpointer data);
 
 #endif /* CALLBACKS_H_ */
